summaryrefslogtreecommitdiffstats
path: root/src/print.cpp
diff options
context:
space:
mode:
authorKrzysztof Kosi??ski <tweenk.pl@gmail.com>2011-08-07 10:53:12 +0000
committerKrzysztof KosiƄski <tweenk.pl@gmail.com>2011-08-07 10:53:12 +0000
commit75976ea07dba9b97186667524d0a76603de416af (patch)
tree4cb68dabb3cb7d5219e6ed6b660f0ded13fc25d3 /src/print.cpp
parentFix compilation (oops). (diff)
downloadinkscape-75976ea07dba9b97186667524d0a76603de416af.tar.gz
inkscape-75976ea07dba9b97186667524d0a76603de416af.zip
Rewrite NRArena -> Inkscape::Drawing. Call render and update
methods on the Drawing rather than on the root DrawingItem. (bzr r10347.1.25)
Diffstat (limited to 'src/print.cpp')
-rw-r--r--src/print.cpp13
1 files changed, 6 insertions, 7 deletions
diff --git a/src/print.cpp b/src/print.cpp
index 29c5b0ed2..2eadf0fa9 100644
--- a/src/print.cpp
+++ b/src/print.cpp
@@ -15,7 +15,7 @@
# include "config.h"
#endif
-#include "display/nr-arena.h"
+#include "display/drawing.h"
#include "display/drawing-item.h"
#include "inkscape.h"
#include "desktop.h"
@@ -117,21 +117,20 @@ sp_print_document_to_file(SPDocument *doc, gchar const *filename)
/* Start */
context.module = mod;
/* fixme: This has to go into module constructor somehow */
/* Create new arena */
mod->base = doc->getRoot();
- mod->arena = NRArena::create();
+ Inkscape::Drawing drawing;
mod->dkey = SPItem::display_key_new(1);
- mod->root = (mod->base)->invoke_show(mod->arena, mod->dkey, SP_ITEM_SHOW_DISPLAY);
+ mod->root = (mod->base)->invoke_show(drawing, mod->dkey, SP_ITEM_SHOW_DISPLAY);
+ drawing.setRoot(mod->root);
/* Print document */
ret = mod->begin(doc);
(mod->base)->invoke_print(&context);
ret = mod->finish();
- /* Release arena */
+ /* Release drawing items */
(mod->base)->invoke_hide(mod->dkey);
mod->base = NULL;
- nr_object_unref((NRObject *) mod->arena);
mod->root = NULL; // should be deleted by invoke_hide
- mod->arena = NULL;
/* end */
mod->set_param_string("destination", oldoutput);
@@ -117,21 +117,20 @@ sp_print_document_to_file(SPDocument *doc, gchar const *filename)
context.module = mod;
/* fixme: This has to go into module constructor somehow */
- /* Create new arena */
+ /* Create new drawing */
mod->base = doc->getRoot();